@@ -1,8 +1,9 @@
 {-# LANGUAGE CPP #-}
-#if !defined(SAFE) && defined(__GLASGOW_HASKELL__) && __GLASGOW_HASKELL__ >= 704
+#if !defined(SAFE) && defined(__GLASGOW_HASKELL__)
 #define UNSAFE
 {-# LANGUAGE Unsafe #-}
 #endif
+{-# OPTIONS_GHC -Wno-redundant-constraints #-} -- they aren't redundant!
 -----------------------------------------------------------------------------
 -- |
 -- Copyright   :  (C) 2008-2015 Edward Kmett
@@ -24,7 +25,7 @@ import Data.Void
 import Unsafe.Coerce
 #endif
 
--- | If 'Void' is uninhabited than any 'Functor' that holds only values of the type 'Void'
+-- | If 'Void' is uninhabited then any 'Functor' that holds only values of the type 'Void'
 -- is holding no values.
 --
 -- This is only safe for valid functors that do not perform GADT-like analysis on the argument.
